@@ -12,7 +12,7 @@ use File::Temp;
 use File::Which;
 use POSIX qw(SIGTERM SIGKILL WNOHANG setuid);
 
-our $VERSION = '1.20_01';
+our $VERSION = '1.20_02';
 our $errstr;
 
 # Various paths that Postgres gets installed under, sometimes with a version on the end,
@@ -62,13 +62,18 @@ has auto_start => (
 has base_dir => (
   is => "rw",
   default => sub {
-    File::Temp::newdir(
-        'temp.XXXX',
+    File::Temp->newdir(
+        'pgtest.XXXXX',
         CLEANUP => $ENV{TEST_POSTGRESQL_PRESERVE} ? undef : 1,
         EXLOCK  => 0,
         TMPDIR  => 1
     );
   },
+  coerce => fun ($newval) {
+    # Ensure base_dir is absolute; usually only the case if the user set it.
+    # Avoid munging objects such as File::Temp
+    ref $newval ? $newval : File::Spec->rel2abs($newval);
+  },
 );
 
 has initdb => (
@@ -150,8 +155,6 @@ method BUILD($) {
         $self->uid($a[2]);
     }
 
-    # Ensure base_dir is absolute; usually only the case if the user set it.
-    $self->base_dir( File::Spec->rel2abs( $self->base_dir ) );
     # Ensure base dir is writable by our target uid, if we were running as root
     chown $self->uid, -1, $self->base_dir
         if defined $self->uid;
